@@ -221,7 +221,7 @@ void makeSelfArcs(edge_t * e, int stepx)
     if (cnt == 1 || Concentrate) {
 	edge_t *edges1[1];
 	edges1[0] = e;
-	makeSelfEdge(edges1, 0, 1, stepx, stepx, &sinfo);
+	makeSelfEdge(edges1, 1, stepx, stepx, &sinfo);
 	if (ED_label(e))
 	    updateBB(agraphof(agtail(e)), ED_label(e));
 	makePortLabels(e);
@@ -231,7 +231,7 @@ void makeSelfArcs(edge_t * e, int stepx)
 	    edges[i] = e;
 	    e = ED_to_virt(e);
 	}
-	makeSelfEdge(edges, 0, cnt, stepx, stepx, &sinfo);
+	makeSelfEdge(edges, cnt, stepx, stepx, &sinfo);
 	for (size_t i = 0; i < cnt; i++) {
 	    e = edges[i];
 	    if (ED_label(e))
@@ -651,6 +651,20 @@ static int spline_edges_(graph_t *g, expand_t *pmargin, int edgetype) {
 	    node_t *head = aghead(e);
 	    if (useEdges && ED_spl(e)) {
 		addEdgeLabels(e);
+		if (Nop == 3 && ED_spl(e)->size > 0) {
+		    // use first bezier, start point and end point will lost
+		    if (ED_spl(e)->size > 1) {
+			agwarningf("edge %s -> %s : set more than one spline. First used, other dropped.\n", agnameof(n), agnameof(head));
+		    }
+		    bezier *bez = ED_spl(e)->list;
+		    size_t sz = bez->size;
+		    bez->size = 0;
+		    pointf *pb = bez->list;
+		    bez->list = NULL;
+		    gv_free_splines(e);
+		    clip_and_install(e, head, pb, sz, &sinfo);
+		    free(pb);
+		}
 	    } 
 	    else if (ED_count(e) == 0) continue;  /* only do representative */
 	    else if (n == head) {    /* self arc */
